@@ -1,4 +1,4 @@
-# $Id: Flock.pm,v 1.5 2008/11/16 21:15:04 dk Exp $
+# $Id: Flock.pm,v 1.6 2008/12/17 10:05:06 dk Exp $
 package IO::Lambda::Flock;
 use vars qw($DEBUG @ISA @EXPORT_OK);
 @ISA = qw(Exporter);
@@ -72,7 +72,8 @@ IO::Lambda::Flock - lambda-style file locking
 
 =head1 DESCRIPTION
 
-The module implements a non-blocking flock(2) wrapper by polling
+The module provides file locking interface for the lambda style,
+implemented by using non-blocking, periodic polling of flock(2).
 
 =head1 SYNOPSIS
 
@@ -82,16 +83,16 @@ The module implements a non-blocking flock(2) wrapper by polling
 
 =item flock($filehandle, %options) -> ($lock_obtained = 1 | $timeout = 0)
 
-Waits for lock to be obtained, or expired. If succeeds, the (shared or
-exclusive) lock is already obtained by C<flock($filehandle, LOCK_NB)> call.
-Options:
+Waits until the file lock is obtained or the timeout is expired. When successful,
+the (shared or exclusive) lock on C<$filehandle> is acquired by C<flock($filehandle,
+LOCK_NB)> call. Options:
 
 =over
 
 =item C<timeout> or C<deadline>
 
-These two options are synonyms, both declare when the waiting for the lock
-should give up. If undef, timeout never occurs.
+These two options are synonyms, both declare the moment when the lambda waiting
+for the lock should give up. If undef, timeout never occurs.
 
 =item shared
 
@@ -99,8 +100,8 @@ If set, C<LOCK_SH> is used, otherwise C<LOCK_EX>.
 
 =item frequency
 
-Defines how often the polling for lock release should occur. If left undefined,
-polling occurs in idle time, when the other events are dispatched.
+Defines how often the polling for the lock should occur. If left undefined,
+polling occurs during idle time, when other events are dispatched.
 
 =back
 
